@@ -28,6 +28,20 @@ namespace ze_lib
             result = getTable( ZE_API_VERSION_CURRENT, &zeDdiTable.Global );
         }
 
+        if( ZE_RESULT_SUCCESS == result )
+        {
+            auto getTable = reinterpret_cast<ze_pfnGetRTASBuilderExpProcAddrTable_t>(
+                GET_FUNCTION_PTR(loader, "zeGetRTASBuilderExpProcAddrTable") );
+            result = getTable( ZE_API_VERSION_CURRENT, &zeDdiTable.RTASBuilderExp );
+        }
+
+        if( ZE_RESULT_SUCCESS == result )
+        {
+            auto getTable = reinterpret_cast<ze_pfnGetRTASParallelOperationExpProcAddrTable_t>(
+                GET_FUNCTION_PTR(loader, "zeGetRTASParallelOperationExpProcAddrTable") );
+            result = getTable( ZE_API_VERSION_CURRENT, &zeDdiTable.RTASParallelOperationExp );
+        }
+
         if( ZE_RESULT_SUCCESS == result )
         {
             auto getTable = reinterpret_cast<ze_pfnGetDriverProcAddrTable_t>(
@@ -35,6 +49,13 @@ namespace ze_lib
             result = getTable( ZE_API_VERSION_CURRENT, &zeDdiTable.Driver );
         }
 
+        if( ZE_RESULT_SUCCESS == result )
+        {
+            auto getTable = reinterpret_cast<ze_pfnGetDriverExpProcAddrTable_t>(
+                GET_FUNCTION_PTR(loader, "zeGetDriverExpProcAddrTable") );
+            result = getTable( ZE_API_VERSION_CURRENT, &zeDdiTable.DriverExp );
+        }
+
         if( ZE_RESULT_SUCCESS == result )
         {
             auto getTable = reinterpret_cast<ze_pfnGetDeviceProcAddrTable_t>(
@@ -201,11 +222,26 @@ namespace ze_lib
             result = zeGetGlobalProcAddrTable( ZE_API_VERSION_CURRENT, &zeDdiTable.Global );
         }
 
+        if( ZE_RESULT_SUCCESS == result )
+        {
+            result = zeGetRTASBuilderExpProcAddrTable( ZE_API_VERSION_CURRENT, &zeDdiTable.RTASBuilderExp );
+        }
+
+        if( ZE_RESULT_SUCCESS == result )
+        {
+            result = zeGetRTASParallelOperationExpProcAddrTable( ZE_API_VERSION_CURRENT, &zeDdiTable.RTASParallelOperationExp );
+        }
+
         if( ZE_RESULT_SUCCESS == result )
         {
             result = zeGetDriverProcAddrTable( ZE_API_VERSION_CURRENT, &zeDdiTable.Driver );
         }
 
+        if( ZE_RESULT_SUCCESS == result )
+        {
+            result = zeGetDriverExpProcAddrTable( ZE_API_VERSION_CURRENT, &zeDdiTable.DriverExp );
+        }
+
         if( ZE_RESULT_SUCCESS == result )
         {
             result = zeGetDeviceProcAddrTable( ZE_API_VERSION_CURRENT, &zeDdiTable.Device );
